/* board.c - Board-specific hooks */

/*
 * Copyright (c) 2017 Intel Corporation
 * Additional Copyright (c) 2018 Espressif Systems (Shanghai) PTE LTD
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <stdio.h>
#include "driver/gpio.h"
#include "driver/rtc_io.h"
#include "esp_log.h"
#include "board.h"

#define TAG "BOARD"

struct _led_state led_state[3] = {
    { LED_OFF, LED_OFF, LED_R, "red"   },
    { LED_OFF, LED_OFF, LED_G, "green" },
    { LED_OFF, LED_OFF, LED_B, "blue"  },
};

struct _motion_state motion_state = { MOTION_NOT_FOUND, INPUT };

void change_read_state(uint8_t state) {
	gpio_set_level(SENSOR_TOGGLE, state);
}

void board_led_operation(uint8_t pin, uint8_t onoff)
{
    for (int i = 0; i < 3; i++) {
        if (led_state[i].pin != pin) {
            continue;
        }
        if (onoff == led_state[i].previous) {
            ESP_LOGW(TAG, "led %s is already %s",
                     led_state[i].name, (onoff ? "on" : "off"));
            return;
        }
        gpio_set_level(pin, onoff);
        led_state[i].previous = onoff;
        return;
    }

    ESP_LOGE(TAG, "LED is not found!");
}

int8_t get_sensor_state(void)
{	
	motion_state.previous = gpio_get_level(INPUT);
	if (motion_state.previous == MOTION_FOUND) ESP_LOGI(TAG, "MOTION FOUND");
	else if (motion_state.previous == MOTION_NOT_FOUND) ESP_LOGI(TAG, "MOTION NOT FOUND");
	return motion_state.previous;
}

static void board_led_init(void)
{
    for (int i = 0; i < 3; i++) {
        gpio_reset_pin(led_state[i].pin);
        gpio_set_direction(led_state[i].pin, GPIO_MODE_OUTPUT);
        gpio_set_level(led_state[i].pin, LED_OFF);
        led_state[i].previous = LED_OFF;
    }
	gpio_reset_pin(motion_state.pin);
	gpio_set_direction(motion_state.pin, GPIO_MODE_INPUT);
	gpio_set_pull_mode(motion_state.pin, GPIO_PULLUP_ONLY);
	motion_state.previous = MOTION_NOT_FOUND;
	
	gpio_reset_pin(SENSOR_TOGGLE);
	gpio_set_direction(SENSOR_TOGGLE, GPIO_MODE_OUTPUT);
}

void board_init(void)
{
    board_led_init();	
}
